@@ -119,7 +119,7 @@
 #define	BUFSZ	(LINE_MAX * 2)
 #define	ESC	0x1b
 
-char		**environ,
+char		**evpp,					/* environment ptr   */
 		*progname;
 int		debug,
 		sigrx,
@@ -129,12 +129,12 @@ pid_t		child;
 int		complete_esc(char *buf, int len);
 int		filter(char *, int);
 size_t		mystrcspn(const char *, const char *);
-RETSIGTYPE	reapchild(int);
+void		reapchild(int);
 #if !HAVE_OPENPTY
 int		openpty(int *, int *, char *, struct termios *,
 			struct winsize *);
 #endif
-RETSIGTYPE	sighdlr(int);
+void		sighdlr(int);
 #if !HAVE_UNSETENV
 int		unsetenv(const char *);
 #endif
@@ -162,7 +162,7 @@ main(int argc, char **argv, char **ev)
     struct pollfd	pfds[3];
     struct termios	tios;
 
-    environ = ev;
+    evpp = ev;
 
     /* get just the basename() of our exec() name and strip a .* off the end */
     if ((progname = strrchr(argv[0], '/')) != NULL)
@@ -658,7 +658,7 @@ mystrcspn(const char *s, const char *charset)
     return(len);
 }
 
-RETSIGTYPE
+void
 reapchild(int sig)
 {
     int         status;
@@ -679,7 +679,7 @@ reapchild(int sig)
     return;
 }
 
-RETSIGTYPE
+void
 sighdlr(int sig)
 {
     if (debug)
@@ -695,10 +695,10 @@ unsetenv(const char *name)
    char	**victim,
 	**end;
    int	len;
-   if (environ == NULL)
+   if (evpp == NULL)
 	return(0);
    len = strlen(name);
-   victim = environ;
+   victim = evpp;
    while (*victim != NULL) {
 	if (strncmp(name, *victim, len) == 0 && victim[0][len] == '=')
 	    break;
